@@ -1133,6 +1133,14 @@ impl AsyncClient {
     pub fn stop_stream(&self) {
         self.remove_message_callback();
     }
+
+    /// Returns client ID used for client instance
+    ///
+    /// Client ID is returned as a rust String as set in a
+    /// CreateOptionsBuilder for symmetry
+    pub fn client_id(&self) -> String {
+        self.inner.client_id.clone().into_string().unwrap()
+    }
 }
 
 // The client is safe to send or share between threads.
@@ -1318,4 +1326,18 @@ mod tests {
         assert!(!cli2.is_connected());
         let _ = thr.join().unwrap();
     }
+
+    #[test]
+    fn test_get_client_id() {
+        println!("get client id");
+        let c_id = "test_client_id_can_be_retrieved";
+        let options = CreateOptionsBuilder::new().client_id(c_id).finalize();
+        let client = AsyncClient::new(options);
+        assert!(
+            client.is_ok(),
+            "Error in creating async client with client_id"
+        );
+        let retrieved = client.unwrap().client_id();
+        assert_eq!(retrieved, c_id.to_string());
+    }
 }
